@@ -224,6 +224,8 @@ class AssertTest extends BaseTestCase
             array('range', array(3, 1, 2), false),
             array('oneOf', array(1, array(1, 2, 3)), true),
             array('oneOf', array(1, array('1', '2', '3')), false),
+            array('inArray', array(1, array(1, 2, 3)), true),
+            array('inArray', array(1, array('1', '2', '3')), false),
             array('contains', array('abcd', 'ab'), true),
             array('contains', array('abcd', 'bc'), true),
             array('contains', array('abcd', 'cd'), true),
@@ -295,6 +297,18 @@ class AssertTest extends BaseTestCase
             array('startsWithLetter', array(''), false),
             array('startsWithLetter', array(null), false),
             array('startsWithLetter', array(66), false),
+            array('notStartsWith', array('abcd', 'ab'), false),
+            array('notStartsWith', array('abcd', 'bc'), true),
+            array('notStartsWith', array('', 'bc'), true),
+            array('notStartsWith', array('äþçð', 'äþ'), false),
+            array('notStartsWith', array('äþçð', 'þç'), true),
+            array('notStartsWith', array('', 'þç'), true),
+            array('notStartsWith', array('あいうえ', 'あい'), false),
+            array('notStartsWith', array('あいうえ', 'いう'), true),
+            array('notStartsWith', array('', 'いう'), true),
+            array('notStartsWith', array('😄😑☹️', '😄'), false),
+            array('notStartsWith', array('😄😑☹️', '😑'), true),
+            array('notStartsWith', array('', '😑'), true),
             array('endsWith', array('abcd', 'cd'), true),
             array('endsWith', array('abcd', 'bc'), false),
             array('endsWith', array('', 'bc'), false),
@@ -307,6 +321,18 @@ class AssertTest extends BaseTestCase
             array('endsWith', array('😄😑☹️', '☹️'), true),
             array('endsWith', array('😄😑☹️', '😑'), false),
             array('endsWith', array('', '😑'), false),
+            array('notEndsWith', array('abcd', 'cd'), false),
+            array('notEndsWith', array('abcd', 'bc'), true),
+            array('notEndsWith', array('', 'bc'), true),
+            array('notEndsWith', array('äþçð', 'çð'), false),
+            array('notEndsWith', array('äþçð', 'þç'), true),
+            array('notEndsWith', array('', 'þç'), true),
+            array('notEndsWith', array('あいうえ', 'うえ'), false),
+            array('notEndsWith', array('あいうえ', 'いう'), true),
+            array('notEndsWith', array('', 'いう'), true),
+            array('notEndsWith', array('😄😑☹️', '☹️'), false),
+            array('notEndsWith', array('😄😑☹️', '😑'), true),
+            array('notEndsWith', array('', '😑'), true),
             array('regex', array('abcd', '~^ab~'), true),
             array('regex', array('abcd', '~^bc~'), false),
             array('regex', array('', '~^bc~'), false),
@@ -677,6 +703,8 @@ class AssertTest extends BaseTestCase
             array('eq', array(array(1), array(2)), 'Expected a value equal to array. Got: array'),
             array('eq', array(new ArrayIterator(array()), new stdClass()), 'Expected a value equal to stdClass. Got: ArrayIterator'),
             array('eq', array(1, self::getResource()), 'Expected a value equal to resource. Got: 1'),
+
+            array('lessThan', array(new \DateTime('2020-01-01 00:00:00'), new \DateTime('1999-01-01 00:00:00')), 'Expected a value less than DateTime: "1999-01-01T00:00:00+00:00". Got: DateTime: "2020-01-01T00:00:00+00:00"'),
         );
     }
 
@@ -690,7 +718,7 @@ class AssertTest extends BaseTestCase
         call_user_func_array(array('Webmozart\Assert\Assert', $method), $args);
     }
 
-    public function testAnUnkownMethodThrowsABadMethodCall()
+    public function testAnUnknownMethodThrowsABadMethodCall()
     {
         $this->setExpectedException('\BadMethodCallException');
 
